@@ -1,6 +1,6 @@
 """A FastAPI Framework for things like Database, Redis, Logging, JWT Authentication and Rate Limits"""
 
-__version__ = "1.3.0"
+__version__ = "1.4.6"
 
 from .modules import check_dependencies, disabled_modules
 
@@ -21,4 +21,6 @@ from .jwt_auth import (
 )
 from .logger import get_logger
 from .rate_limit import RateLimitManager, RateLimiter, get_uuid_user_id, RateLimitTime
-from .redis import get_redis, RedisDependency, redis_dependency
+from .redis import get_redis, RedisDependency, redis_dependency, Redis
+from .in_memory_backend import InMemoryBackend, RAMBackend
+from .config import Config, ConfigField
